# Generated by roxygen2: do not edit by hand

S3method(plot,mixpch)
S3method(plot,nphparams)
S3method(print,mixpch)
S3method(print,nphparams)
S3method(vcov,nphparams)
S3method(vcov,myobj)
S3method(coef,myobj)
S3method(print,wlogrank)
S3method(print,wlogrank_max)
export(logrank.maxtest)
export(logrank.test)
export(m2r)
export(nph_gui)
export(nphparams)
export(pchaz)
export(plot_diagram)
export(plot_shhr)
export(plot_subgroups)
export(pop_pchaz)
export(rSurv_conditional_fun)
export(rSurv_fun)
export(sample_conditional_fun)
export(sample_fun)
export(subpop_pchaz)
import(ggplot2)
import(graphics)
import(stats)
importFrom(mvtnorm,pmvnorm)
importFrom(stats,integrate)
importFrom(utils,head)
importFrom(survival,Surv)
importFrom(survival,survfit)
importFrom(survival,coxph)
importFrom(muhaz,muhaz)
importFrom(multcomp,glht)
