## Quick overview

The package includes functions to model survival distributions in terms of piecewise constant hazards and to simulate data from the specified distributions. Also, a function to calculate weighted log-rank tests for the comparison of two hazard functions is included. Finally, a function to calculate a test using the maximum of a set of test statistics from weighted log-rank tests is provided. This test utilizes the asymptotic multivariate normal joint distribition of the separate test statistics. The correlation is estimated from the data.

Select the **<i class="fa fa-file-excel-o"></i> Dataset** tab to load your own data and perform an analysis.

Select the **<i class="fa fa-table"></i> Simulate** tab to create a dataset.

Select the **<i class="fa fa-line-chart"></i> Examples** tab to check some examples.

## More information

This tool is part of an R package. For more information, please contact <a target="_blank" style="font-weight: bold;color:#f8c954;" href="mailto:robin.ristl@meduniwien.ac.at;nicolas.ballarini@meduniwien.ac.at">contact Robin Ristl and Nicolas Ballarini</a>.

## Contact

For any comments or questions, please <a target="_blank" style="font-weight: bold;color:#f8c954;" href="mailto:robin.ristl@meduniwien.ac.at;nicolas.ballarini@meduniwien.ac.at">contact Robin Ristl and Nicolas Ballarini</a>.
